@@ -115,7 +115,7 @@
  *
  * `AdwMessageDialog` supports adding responses in UI definitions by via the
  * `<responses>` element that may contain multiple `<response>` elements, each
- * respresenting a response.
+ * representing a response.
  *
  * Each of the `<response>` elements must have the `id` attribute specifying the
  * response ID. The contents of the element are used as the response label.
@@ -406,22 +406,29 @@ parent_changed_cb (AdwMessageDialog *self)
   set_parent (self, transient_for);
 }
 
-static void
-button_clicked_cb (ResponseInfo *info)
+
+static inline void
+emit_response (AdwMessageDialog *self, GQuark response)
 {
-  AdwMessageDialog *self = info->dialog;
   AdwMessageDialogPrivate *priv = adw_message_dialog_get_instance_private (self);
 
   g_object_ref (self);
   priv->block_close_response = TRUE;
 
   gtk_window_close (GTK_WINDOW (self));
-  g_signal_emit (self, signals[SIGNAL_RESPONSE], info->id, g_quark_to_string (info->id));
+  g_signal_emit (self, signals[SIGNAL_RESPONSE], response, g_quark_to_string (response));
 
   priv->block_close_response = FALSE;
   g_object_unref (self);
 }
 
+
+static void
+button_clicked_cb (ResponseInfo *info)
+{
+  emit_response (info->dialog, info->id);
+}
+
 static GtkWidget *
 create_response_button (AdwMessageDialog *self,
                         ResponseInfo     *info)
@@ -555,7 +562,7 @@ measure_heading (GtkWidget      *widget,
 {
   AdwMessageDialog *self = ADW_MESSAGE_DIALOG (gtk_widget_get_root (widget));
   AdwMessageDialogPrivate *priv = adw_message_dialog_get_instance_private (self);
-  int large_min, large_nat, small_min, small_nat;
+  int large_min, large_nat, small_min, small_nat, for_size_large_label;
 
   if (gtk_widget_has_css_class (GTK_WIDGET (self), "short")) {
     gtk_widget_measure (priv->heading_label_small, orientation, for_size,
@@ -569,7 +576,14 @@ measure_heading (GtkWidget      *widget,
     return;
   }
 
-  gtk_widget_measure (priv->heading_label, orientation, for_size,
+  if (orientation == GTK_ORIENTATION_HORIZONTAL) {
+    gtk_widget_measure (priv->heading_label, GTK_ORIENTATION_HORIZONTAL, -1,
+                        &for_size_large_label, NULL, NULL, NULL);
+  } else {
+    for_size_large_label = -1;
+  }
+
+  gtk_widget_measure (priv->heading_label, orientation, for_size_large_label,
                       &large_min, &large_nat, NULL, NULL);
   gtk_widget_measure (priv->heading_label_small, orientation, for_size,
                       &small_min, &small_nat, NULL, NULL);
@@ -1947,14 +1961,14 @@ adw_message_dialog_set_extra_child (AdwMessageDialog *self,
   g_return_if_fail (ADW_IS_MESSAGE_DIALOG (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   priv = adw_message_dialog_get_instance_private (self);
 
   if (child == priv->child)
     return;
 
+  if (child)
+    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
+
   priv->child = child;
   adw_bin_set_child (ADW_BIN (priv->child_bin), child);
   gtk_widget_set_visible (priv->child_bin, child != NULL);
@@ -2542,8 +2556,9 @@ choose_cancelled_cb (GCancellable *cancellable,
                      GTask        *task)
 {
   AdwMessageDialog *self = g_task_get_source_object (task);
+  AdwMessageDialogPrivate *priv = adw_message_dialog_get_instance_private (self);
 
-  choose_response_cb (self, adw_message_dialog_get_close_response (self), task);
+  emit_response (self, priv->close_response);
 }
 
 /**
